@@ -163,6 +163,7 @@ class Leg(object):
     def invert(self,invert):
         self.__invert = invert
 
+
     def setdefault(self):
         """
         DEPRICATED METHOD - USE .default
@@ -171,10 +172,10 @@ class Leg(object):
 
     def default(self):
         """
-        Sets the limb to the default angle, by dividing the maximum and
+        Sets the limb to the default angle, by subtracting the maximum and
         minimum angles that were set previously
         """
-        self.angle(self.__leg_maxangle - self.__leg_minangle)
+        self.angle = self.__leg_maxangle - self.__leg_minangle
         self.__currentangle = self.__leg_maxangle - self.__leg_minangle
 
     def setbody(self):
@@ -188,10 +189,10 @@ class Leg(object):
         Sets the limb to its body position.
         """
         if not self.__invert:
-            self.angle(self.__leg_minangle)
+            self.angle = self.__leg_minangle
             self.__bodyangle = self.__leg_minangle
         else:
-            self.angle(self.__leg_maxangle)
+            self.angle = self.__leg_maxangle
             self.__bodyangle = self.__leg_maxangle
         self.__currentangle = self.__bodyangle
 
@@ -204,10 +205,10 @@ class Leg(object):
         Sets the limb to its stretch position.
         """
         if not self.__invert:
-            self.angle(self.__leg_maxangle)
+            self.angle = self.__leg_maxangle
             self.__stretchangle = self.__leg_maxangle
         else:
-            self.angle(self.__leg_minangle)
+            self.angle = self.__leg_minangle
             self.__stretchangle = self.__leg_minangle
         self.__currentangle = self.__stretchangle
 
@@ -222,10 +223,10 @@ class Leg(object):
         """
         if not self.invert:
             swing_angle = (self.__leg_minangle / 2) + self.__leg_minangle
-            self.angle(swing_angle)
+            self.angle = swing_angle
         else:
             swing_angle = (self.__leg_maxangle - self.__leg_minangle) / 2
-            self.angle(swing_angle)
+            self.angle = swing_angle
         self.__swingangle = swing_angle
         self.__currentangle = self.__swingangle
 
@@ -234,24 +235,24 @@ class Leg(object):
         raises the limb to its minimum angle
         """
         if not self.invert:
-            self.angle(self.__leg_minangle)
+            self.angle = self.__leg_minangle
         else:
-            self.angle(self.__leg_maxangle)
+            self.angle = self.__leg_maxangle
 
     def down(self):
         """
         lowers the limb to its maximum angle
         """
         if not self.invert:
-            self.angle(self.__leg_maxangle)
+            self.angle = self.__leg_maxangle
         else:
-            self.angle(self.__leg_minangle)
+            self.angle = self.__leg_minangle
 
     def middle(self):
         """
         moves the limb to half way between up and down.
         """
-        self.angle(self.__leg_maxangle - self.__leg_minangle)
+        self.angle = self.__leg_maxangle - self.__leg_minangle
 
     def show(self):
         """
@@ -266,6 +267,7 @@ class Leg(object):
         """
         print("This method is depricated - use .angle instead")
 
+    @angle.setter
     def angle(self, angle):
         """
         Works out the value of the angle by mapping the leg_min and leg_max to
@@ -308,14 +310,14 @@ class Leg(object):
             if self.__currentangle <= self.__leg_maxangle:
                 self.__currentangle += 2
                 # print self.name, "setting angle to ", self.currentAngle
-                self.angle(self.__currentangle)
+                self.angle = self.__currentangle
                 return False
             return True
         elif self.__name == "left_leg_back" or self.__name == "left_leg_front":
             if self.__currentangle >= self.__leg_minangle:
                 self.__currentangle -= 2
                 # print self.name, "setting angle to ", self.currentAngle
-                self.angle(self.__currentangle)
+                self.angle = self.__currentangle
                 return False
             return True
         return True
@@ -329,14 +331,14 @@ class Leg(object):
             if self.__currentangle <= self.__leg_maxangle:
                 self.__currentangle += 2
                 # print self.name, "setting angle to ", self.currentAngle
-                self.angle(self.__currentangle)
+                self.angle = self.__currentangle
                 return False
             return True
         elif self.__name == "right_leg_front" or self.__name == "right_leg_back":
             if self.__currentangle >= self.__leg_minangle:
                 self.__currentangle -= 2
                 # print self.name, "setting angle to ", self.currentAngle
-                self.angle(self.__currentangle)
+                self.angle = self.__currentangle
                 return False
             return True
         return True
@@ -374,23 +376,23 @@ class SmarsRobot(object):
     __name = ""  # the friendly name for the robot - used in console messages.
 
     # add each foot to the feet array
-    __feet.append(Leg(name='left_foot_front', channel=1,
+    __feet.append(Leg(name='LEFT_FOOT_FRONT', channel=1,
                     leg_minangle=50, leg_maxangle=150, invert=False))
-    __feet.append(Leg(name='left_foot_back', channel=3,
+    __feet.append(Leg(name='LEFT_FOOT_BACK', channel=3,
                     leg_minangle=50, leg_maxangle=150, invert=True))
-    __feet.append(Leg(name='right_foot_front', channel=7,
+    __feet.append(Leg(name='RIGHT_FOOT_FRONT', channel=7,
                     leg_minangle=50, leg_maxangle=150, invert=True))
-    __feet.append(Leg(name='right_foot_back', channel=5,
+    __feet.append(Leg(name='RIGHT_FOOT_BACK', channel=5,
                     leg_minangle=50, leg_maxangle=150, invert=False))
 
     # add each leg to the legs array
-    __legs.append(Leg(name='left_leg_front', channel=0,
+    __legs.append(Leg(name='LEFT_LEG_FRONT', channel=0,
                     leg_minangle=9, leg_maxangle=90, invert=True))
-    __legs.append(Leg(name='left_leg_back', channel=2,
+    __legs.append(Leg(name='LEFT_LEG_BACK', channel=2,
                     leg_minangle=90, leg_maxangle=180, invert=False))
-    __legs.append(Leg(name='right_leg_front', channel=6,
+    __legs.append(Leg(name='RIGHT_LEG_FRONT', channel=6,
                     leg_minangle=90, leg_maxangle=180, invert=False))
-    __legs.append(Leg(name='right_leg_back', channel=4,
+    __legs.append(Leg(name='RIGHT_LEG_BACK', channel=4,
                     leg_minangle=9, leg_maxangle=90, invert=True))
     # print "number of legs", len(legs)
 
@@ -439,7 +441,7 @@ class SmarsRobot(object):
         """
         print(self.__name, "sitting Down.")
         for limb in self.__feet:
-            limb.down()
+            self.__feet[limb].down()
 
     def stand(self):
         """
@@ -447,7 +449,7 @@ class SmarsRobot(object):
         """
         print(self.name, "standing up.")
         for limb in self.__feet:
-            limb.up()
+            self.__feet[limb].up()
 
     def swing(self):
         """
